@@ -1,5 +1,5 @@
 from __future__ import absolute_import
-# Copyright (c) 2010-2018 openpyxl
+# Copyright (c) 2010-2019 openpyxl
 
 """
 Read a chart
@@ -33,5 +33,8 @@ def read_chart(chartspace):
     chart.floor = cs.chart.floor
     chart.sideWall = cs.chart.sideWall
     chart.backWall = cs.chart.backWall
+    chart.pivotSource = cs.pivotSource
+    chart.pivotFormats = cs.chart.pivotFmts
+    chart.idx_base = min(s.idx for s in chart.series)
 
     return chart
