@@ -15,7 +15,7 @@ from openpyxl.compat import safe_string
 
 from .colors import ColorDescriptor, Color
 
-from openpyxl.xml.functions import Element, localname, safe_iterator
+from openpyxl.xml.functions import Element, localname
 from openpyxl.xml.constants import SHEET_MAIN_NS
 
 
