@@ -2,7 +2,7 @@ from __future__ import absolute_import
 # Copyright (c) 2010-2019 openpyxl
 
 import operator
-from openpyxl.compat import accumulate, zip
+from openpyxl.compat import accumulate
 
 
 def dataframe_to_rows(df, index=True, header=True):
