@@ -1,5 +1,5 @@
 from __future__ import absolute_import
-# Copyright (c) 2010-2017 openpyxl
+# Copyright (c) 2010-2019 openpyxl
 
 
 """Definitions for openpyxl shared exception classes."""
@@ -22,10 +22,6 @@ class SheetTitleException(Exception):
     """Error for bad sheet names."""
 
 
-class InsufficientCoordinatesException(Exception):
-    """Error for partially specified cell coordinates."""
-
-
 class InvalidFileException(Exception):
     """Error for trying to open a non-ooxml file."""
 
