@@ -1,9 +1,9 @@
 from __future__ import absolute_import
-# Copyright (c) 2010-2018 openpyxl
+# Copyright (c) 2010-2019 openpyxl
 
 from copy import copy
 
-from openpyxl.compat import safe_string, deprecated
+from openpyxl.compat import safe_string
 from openpyxl.utils import (
     get_column_interval,
     column_index_from_string,
@@ -19,8 +19,6 @@ from openpyxl.descriptors import (
 )
 from openpyxl.descriptors.serialisable import Serialisable
 from openpyxl.styles.styleable import StyleableObject
-from openpyxl.styles.cell_style import StyleArray
-
 from openpyxl.utils.bound_dictionary import BoundDictionary
 from openpyxl.xml.functions import Element
 
@@ -123,7 +121,7 @@ class RowDimension(Dimension):
 class ColumnDimension(Dimension):
     """Information about the display properties of a column."""
 
-    width = Float(allow_none=True)
+    width = Float()
     bestFit = Bool()
     auto_size = Alias('bestFit')
     index = String()
@@ -137,7 +135,7 @@ class ColumnDimension(Dimension):
     def __init__(self,
                  worksheet,
                  index='A',
-                 width=None,
+                 width=0,
                  bestFit=False,
                  hidden=False,
                  outlineLevel=0,
@@ -167,7 +165,7 @@ class ColumnDimension(Dimension):
     @property
     def customWidth(self):
         """Always true if there is a width for the column"""
-        return self.width is not None
+        return bool(self.width)
 
 
     def reindex(self):
@@ -180,7 +178,8 @@ class ColumnDimension(Dimension):
 
     def to_tree(self):
         attrs = dict(self)
-        return Element("col", **attrs)
+        if set(attrs) != set(['min', 'max']):
+            return Element("col", **attrs)
 
 
 class DimensionHolder(BoundDictionary):
@@ -191,29 +190,35 @@ class DimensionHolder(BoundDictionary):
     def __init__(self, worksheet, reference="index", default_factory=None):
         self.worksheet = worksheet
         self.max_outline = None
+        self.default_factory = default_factory
         super(DimensionHolder, self).__init__(reference, default_factory)
 
 
     def group(self, start, end=None, outline_level=1, hidden=False):
-        """allow grouping a range of consecutive columns together
+        """allow grouping a range of consecutive rows or columns together
 
-        :param start: first column to be grouped (mandatory)
-        :param end: last column to be grouped (optional, default to start)
+        :param start: first row or column to be grouped (mandatory)
+        :param end: last row or column to be grouped (optional, default to start)
         :param outline_level: outline level
         :param hidden: should the group be hidden on workbook open or not
         """
         if end is None:
             end = start
 
-        new_dim = self[start]
-        new_dim.outline_level = outline_level
-        new_dim.hidden = hidden
-
-        work_sequence = get_column_interval(start, end)[1:]
-        for column_letter in work_sequence:
-            if column_letter in self:
-                del self[column_letter]
-        new_dim.min, new_dim.max = map(column_index_from_string, (start, end))
+        if isinstance(self.default_factory(), ColumnDimension):
+            new_dim = self[start]
+            new_dim.outline_level = outline_level
+            new_dim.hidden = hidden
+            work_sequence = get_column_interval(start, end)[1:]
+            for column_letter in work_sequence:
+                if column_letter in self:
+                    del self[column_letter]
+            new_dim.min, new_dim.max = map(column_index_from_string, (start, end))
+        elif isinstance(self.default_factory(), RowDimension):
+            for el in range(start, end + 1):
+                new_dim = self.worksheet.row_dimensions[el]
+                new_dim.outline_level = outline_level
+                new_dim.hidden = hidden
 
 
     def to_tree(self):
