@@ -1,11 +1,9 @@
-# -*- coding: utf-8 -*-
 from __future__ import absolute_import
-# Copyright (c) 2010-2016 openpyxl
+# Copyright (c) 2010-2019 openpyxl
 
 
 """Write the theme xml based on a fixed string."""
 
-# package imports
 
 theme_xml = """<?xml version="1.0"?>
 <a:theme xmlns:a="http://schemas.openxmlformats.org/drawingml/2006/main" name="Office Theme">
@@ -289,7 +287,3 @@ theme_xml = """<?xml version="1.0"?>
   <a:extraClrSchemeLst/>
 </a:theme>
 """
-
-def write_theme():
-    """Write the theme xml."""
-    return theme_xml
